@@ -26,6 +26,8 @@
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/interfaces/ianjuta-file.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
+#include <libanjuta/interfaces/ianjuta-file-manager.h>
+#include <libanjuta/interfaces/ianjuta-project-manager.h>
 #include <libanjuta/interfaces/ianjuta-preferences.h>
 #include <libanjuta/interfaces/ianjuta-vcs.h>
 
@@ -34,7 +36,7 @@
 #include "cvs-interface.h"
 
 #define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-cvs.ui"
-#define ICON_FILE "anjuta-cvs-plugin.png"
+#define ICON_FILE "anjuta-cvs-plugin-48.png"
 
 static gpointer parent_class;
 
@@ -165,12 +167,12 @@ static GtkActionEntry popup_actions_cvs[] = {
 };
 
 static void
-value_added_fm_current_uri (AnjutaPlugin *plugin, const char *name,
+value_added_fm_current_file (AnjutaPlugin *plugin, const char *name,
 							const GValue *value, gpointer data)
 {
 	AnjutaUI *ui;
 	GtkAction *cvs_menu_action;
-	const gchar *uri;
+	gchar *uri;
 	GnomeVFSURI *cvs_uri = NULL;
 	gchar *cvs_text_uri = NULL;
 	gchar *cvs_dir;
@@ -179,7 +181,8 @@ value_added_fm_current_uri (AnjutaPlugin *plugin, const char *name,
 	GnomeVFSFileInfo info;
 	GnomeVFSResult result;
 	
-	uri = g_value_get_string (value);
+	GFile* file = G_FILE (g_value_get_object (value));
+	uri = g_file_get_uri (file);
 	filename = gnome_vfs_get_local_path_from_uri (uri);
 	g_return_if_fail (filename != NULL);
 
@@ -226,10 +229,11 @@ value_added_fm_current_uri (AnjutaPlugin *plugin, const char *name,
 		g_object_set (G_OBJECT (cvs_menu_action), "sensitive", FALSE, NULL);
 	}
 	g_free (cvs_dir);
+	g_free (uri);
 }
 
 static void
-value_removed_fm_current_uri (AnjutaPlugin *plugin,
+value_removed_fm_current_file (AnjutaPlugin *plugin,
 							  const char *name, gpointer data)
 {
 	AnjutaUI *ui;
@@ -292,7 +296,7 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 							const GValue *value, gpointer data)
 {
 	AnjutaUI *ui;
-	gchar *uri;
+	GFile* file;
 	GObject *editor;
 	
 	editor = g_value_get_object (value);
@@ -307,16 +311,15 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 		g_free (cvs_plugin->current_editor_filename);
 	cvs_plugin->current_editor_filename = NULL;
 	
-	uri = ianjuta_file_get_uri (IANJUTA_FILE (editor), NULL);
-	if (uri)
+	file = ianjuta_file_get_file (IANJUTA_FILE (editor), NULL);
+	if (file)
 	{
 		gchar *filename;
 		
-		filename = gnome_vfs_get_local_path_from_uri (uri);
+		filename = g_file_get_path (file);
 		g_return_if_fail (filename != NULL);
 		cvs_plugin->current_editor_filename = filename;
-		g_free (uri);
-		// update_module_ui (cvs_plugin);
+		g_object_unref (file);
 	}
 }
 
@@ -362,15 +365,15 @@ activate_plugin (AnjutaPlugin *plugin)
 	
 	/* Add watches */
 	cvs_plugin->fm_watch_id = 
-		anjuta_plugin_add_watch (plugin, "file_manager_current_uri",
-								 value_added_fm_current_uri,
-								 value_removed_fm_current_uri, NULL);
+		anjuta_plugin_add_watch (plugin, IANJUTA_FILE_MANAGER_SELECTED_FILE,
+								 value_added_fm_current_file,
+								 value_removed_fm_current_file, NULL);
 	cvs_plugin->project_watch_id = 
-		anjuta_plugin_add_watch (plugin, "project_root_uri",
+		anjuta_plugin_add_watch (plugin, IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI,
 								 value_added_project_root_uri,
 								 value_removed_project_root_uri, NULL);
 	cvs_plugin->editor_watch_id = 
-		anjuta_plugin_add_watch (plugin, "document_manager_current_editor",
+		anjuta_plugin_add_watch (plugin, IANJUTA_DOCUMENT_MANAGER_CURRENT_DOCUMENT,
 								 value_added_current_editor,
 								 value_removed_current_editor, NULL);
 	return TRUE;
@@ -406,14 +409,14 @@ static void
 finalize (GObject *obj)
 {
 	// CVSPlugin *plugin = ANJUTA_PLUGIN_CVS (obj);
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (G_OBJECT(obj)));
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 static void
 dispose (GObject *obj)
 {
 	// CVSPlugin *plugin = ANJUTA_PLUGIN_CVS (obj);
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (G_OBJECT(obj)));
+	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
 
 static void
